@@ -6,7 +6,8 @@ import urlparse
 
 class ApiGateway(BaseResponseHandler):
     def on_execution(self, event):
-        return extract_body(event)
+        event['body'] = extract_body(event)
+        return event
 
     def on_exception(self, ex):
         if type(ex) == TimeoutError:
